Containers
==========

Winners
-------
.. autoclass:: poisson_approval.Winners
    :members:

Scores
------
.. autoclass:: poisson_approval.Scores
    :members:

AnalyzedStrategies
------------------
.. autoclass:: poisson_approval.AnalyzedStrategies
    :members:
